function EPrice=EPDRT(lpr_ini0, parameter)

%==========================================================================
%This function computes the expected PD ratio of the asset at time T using
%lpr_ini0 as the log pd ratio after announcement. This is used to compute 
%the risk premium upon announcement.
%==========================================================================
%Input: lpr_ini0: the log PD ratio at the set of grid points in m_vec
%Output:EPrice: the expected PD ratio at the set of grid points in m_vec
%==========================================================================
dim_time= parameter.dim_solu_time;
dim_m   = parameter.dim_m;
m_vec   = parameter.m_vec;
t_low   = parameter.t_low;
t_hig   = parameter.t_hig;
q_grid  = parameter.q_solu_grid;
q_ini   = parameter.q_ini;

fun_data=spdata(0,m_vec,lpr_ini0,lpr_ini0);
lpr_deri=spvalue(m_vec, fun_data, 1);
EPrice=zeros(dim_m,1);

q_termi=q_grid(dim_time) - q_ini;
[node,wght]=qnwnorm(8, 0, q_termi);
node_radi=max(abs(node));
for j_m=1:dim_m;
    if (m_vec(j_m)-node_radi>=t_low && m_vec(j_m)+node_radi<=t_hig);
        %If m is in the interior, use Gaussian quadrature.
        t_node=m_vec(j_m)+node;
        lpr_node=spvalue(t_node, fun_data,0);
        EPrice(j_m)=wght'*exp(lpr_node);
    else
        %If m is close to the boundary, use local method.
        EPrice(j_m)=exp(lpr_ini0(j_m)+0.5*(lpr_deri(j_m)^2)*q_termi);
    end
end
end