function lpr_termi=LPDRT(lpr_ini0, parameter)

%==========================================================================
%This function takes the log pdr at time 0, after information release as
%given and compute the log pdr at time T, right before the next information
%release. There is no iteration here. It uses the SDF to evaluate the pd
%ratio.
%==========================================================================
%Input: lpr_ini0 is the log pdr at time zero.
%Output:lpr_termi is the log pdr at time TTT in the previous cycle.
%==========================================================================
betta=parameter.betta;
gama=parameter.gama;
a_ou=parameter.a_ou;

dim_time= parameter.dim_solu_time;
dim_m   = parameter.dim_m;
m_vec   = parameter.m_vec;
t_low   = parameter.t_low;
t_hig   = parameter.t_hig;
q_grid  = parameter.q_solu_grid;
q_ini   = parameter.q_ini;

BBB=(1-gama)/(a_ou+betta);
fun_data=spdata(0,m_vec,lpr_ini0,lpr_ini0);
lpr_deri=spvalue(m_vec, fun_data, 1);
lpr_termi=zeros(dim_m,1);

q_termi=q_grid(dim_time) - q_ini;   %The variance of post-announcement 
%                   Note that Var(t) = Var[E(t|signal] + Var(t|signal).
[node,wght]=qnwnorm(8, 0, q_termi);
node_radi=max(abs(node));
for j_m=1:dim_m;
    if (m_vec(j_m)-node_radi>=t_low && m_vec(j_m)+node_radi<=t_hig);
        %If m is in the interior, use Gaussian quadrature. 
        t_node=m_vec(j_m)+node;
        lpr_node=spvalue(t_node, fun_data,0);
        num=wght'*exp(BBB*t_node+lpr_node);
        lpr_termi(j_m)=log(num)-BBB*m_vec(j_m)-0.5*BBB^2*q_termi;
    else
        %If m is close to boundary, use local method.
        lpr_termi(j_m)=lpr_ini0(j_m)+lpr_deri(j_m)*(BBB+0.5*lpr_deri(j_m))*q_termi;
    end
end
end