function lpr_output = LPDR_0(lpr_ini, parameter, mod_case)

%==========================================================================
%This function takes the log pd ratio at terminal time, lpr_ini as given 
%and iterate to compute the log pd ratio at time 0.
%If mod_case == 'repeat', then the output is a dim_m by dim_solu_time
%   matrix, where each column of the matrix is the log pdr at a particular
%   time point for each m in the domain.
%If mod_case == 'infity', then the output is a dim_m by 1 vector of the
%   log pdr at time 0.
%==========================================================================
%Input: lpr_ini is the vector of log pd ratio at the terminal time.
%Output:Case 'repeat': solve for the model with periodic info release.
%       lpr_output is a dim_mXdim_solu_time matrix, where every column is 
%       the log pd ratio of the asset at a particular point in time_grid.
%       Case 'infity': Solve for the pd ratio for the case of complete
%       information at time 0, and no learning afterwards. lpr_ini is the
%       initial guess of log pdr. It should be computed from the model with
%       learning steady state.
%==========================================================================
betta   = parameter.betta;
gama    = parameter.gama;
ssai    = parameter.ssai;
t_bar   = parameter.t_bar;
a_ou    = parameter.a_ou;
sig     = parameter.sig;
phi     = parameter.phi;
phi_2   = parameter.phi_2;
mud     = parameter.mud;
dim_m   = parameter.dim_m;
m_vec   = parameter.m_vec;
BBB     = (1-gama)/(a_ou+betta);

switch mod_case;
    case 'repeat'
        dim_time= parameter.dim_solu_time;
        q_grid  = parameter.q_solu_grid;
        del     = parameter.del_solu;
        cf_ind  = 1;
    case 'infity'
        dim_time= parameter.dim_inf_time;
        q_grid  = parameter.q_inf_grid;
        del     = parameter.del_inf;
        cf_ind  = 1;
    case 'bond'
        dim_time= parameter.dim_solu_time;
        q_grid  = parameter.q_solu_grid;
        del     = parameter.del_solu;
        mud     = 0;
        phi     = 0;
        phi_2   = 0;
        cf_ind  = 0;
    case 'nominl'
        dim_time= parameter.dim_solu_time;
        q_grid  = parameter.q_solu_grid;
        del     = parameter.del_solu;
        cf_ind  = 0;
end

lpr_mat=zeros(dim_m, dim_time);
lpr_mat(:,dim_time) = lpr_ini;

for ind=1:dim_time-1;
    j_time=dim_time-ind;
    lpr_plus=lpr_mat(:,j_time+1);
    
%     bmm_vec=betta+t_bar-mud+(1-phi)*(m_vec-t_bar);
%     bmm_vec=bmm_vec+(phi_2-1)*(gama*sig^2+(gama-1)/(a_ou+betta)*q_grid(j_time));
%     mut_vec=a_ou*(m_vec-t_bar)+(gama-phi_2)*q_grid(j_time);
%     mut_vec=mut_vec+(gama-1)/(a_ou+betta)*(q_grid(j_time)/sig)^2;   %This 
%     %is the vector mu(m,t) as function of m at time j_time.
    
    rmm_vec     = betta+m_vec/ssai-0.5*gama*(1+1/ssai)*sig^2;
    rmm_vec     = rmm_vec-(gama-1/ssai)/(1-gama)*BBB*q_grid(j_time);
    rmm_vec     = rmm_vec+0.5*(1/ssai-gama)*(1-1/ssai)/((1-gama)^2)*(BBB*q_grid(j_time)/sig)^2;
    sig_pai     = gama*sig-(1/ssai-gama)/(1-gama)*BBB*q_grid(j_time)/sig;
    bmm_vec     = rmm_vec-mud-phi*(m_vec-t_bar)+phi_2*sig*sig_pai;
    mut_vec     = a_ou*(m_vec-t_bar)+q_grid(j_time)*sig_pai/sig-phi_2*q_grid(j_time);
    
    
    fun_data=spdata(0,m_vec,lpr_plus,lpr_plus);
    lpr_deri=spvalue(m_vec,fun_data,1);
    temp_vec=-(bmm_vec+lpr_deri.*mut_vec)*del;
    temp_vec=temp_vec+0.5*del*(lpr_deri.^2)*(q_grid(j_time)/sig)^2;
    temp_vec=log(cf_ind*del+exp(lpr_plus+temp_vec));
    lpr_mat(:,j_time)=temp_vec;
end
switch mod_case;
    case 'repeat'
        lpr_output  = lpr_mat;
    otherwise
        lpr_output  = lpr_mat(:,1);
end
end