function lpr=LPDR_CompInfo(parameter, del, maxit, tol, lpr_ini)

%==========================================================================
%This function compute the log price-to-dividend ratio in the complete
%information economy with no learning. 
%==========================================================================
%Input: lpr_ini is the vector of log pd ratio at time TTT.
%Output:lpr_mat is a dim_mXdim_time matrix, where every column is the log 
%       pd ratio of the asset at a particular point in time_grid.
%==========================================================================
betta   = parameter.betta;
gama    = parameter.gama;

t_bar   = parameter.t_bar;
a_ou    = parameter.a_ou;
sig     = parameter.sig;
sig_t   = parameter.sig_t;
phi     = parameter.phi;
phi_2   = parameter.phi_2;
mud     = parameter.mud;
dim_m   = parameter.dim_m;
m_vec   = parameter.m_vec;

if nargin<4;
        lpr_ini=1/(betta-mud+t_bar)*ones(dim_m,1);
end

btt_vec=betta+t_bar-mud+(1-phi)*(m_vec-t_bar)+(phi_2-1)*gama*sig^2;
mut_vec=a_ou*(m_vec-t_bar)+(gama-1)/(a_ou+betta)*sig_t^2;

j_iter=1;
epsilon=1.0;
while (epsilon>tol && j_iter<maxit);
    fun_data=spdata(0,m_vec,lpr_ini,lpr_ini);
    lpr_deri=spvalue(m_vec,fun_data,1);
    
    temp_vec=-(btt_vec+lpr_deri.*mut_vec)*del;
    temp_vec=temp_vec+0.5*del*(lpr_deri.^2)*sig_t^2;
    temp_vec=log(del+exp(lpr_ini+temp_vec));
    epsilon=sqrt(sum((lpr_ini-temp_vec).^2)/dim_m);
    if (j_iter/10000==floor(j_iter/10000));
        disp(['Total Number of Iteration:   ', num2str(j_iter), ...
            '  Residue:', num2str(epsilon)]);
    end
    lpr_ini=temp_vec;
    j_iter=j_iter+1;
end
lpr=lpr_ini;
end