function output=Q_Grid(q_ini, time_grid, parameter, mod_case)

%==========================================================================
%This function computes the vector of posterior variance at time_grid with
%the inital value of Q being q_ini.
%Input: q_ini: the initial level of posterior variance.
%       time_grid: calendar time, which will be transformed into cycle time
%Output:output is the grid points of posterior belief computed at cycle
%       time.
%==========================================================================

a_ou    = parameter.a_ou;
sig     = parameter.sig;
sig_t   = parameter.sig_t;
TTT     = parameter.TTT;

a_hat=sqrt(a_ou^2+(sig_t/sig)^2);
t_start=log(sig_t^2+q_ini*(a_hat-a_ou));
t_start=t_start-log(sig_t^2-q_ini*(a_hat+a_ou));
t_start=t_start/2/a_hat;

switch mod_case;
    case 'repeat'
        if max(time_grid) > TTT+1.e-5;
        time_grid=mod(time_grid, TTT);
        end
end

time_grid=time_grid+t_start;
exp_vec=exp(-2*a_hat*time_grid);        %exp(-2t*a_hat)
output=sig_t^2*(1-exp_vec);
output=output./(a_ou+a_hat+(a_hat-a_ou)*exp_vec);   %Vector of posterior var
end