function [output_premium, output_rfree]=Risk_Pre(lpdr_mat, time, parameter)
%==========================================================================
%This function computes the intantaneous risk premium in the interior.
%Input: lpdr_mat: the matrix of log pdr ratios.
%       time:     Calendar time, which will be tranformed in cycle time.
%Output:output_premium: the dim_mX1 vector of instantaneous risk premium at 
%           time t as a function of m.
%       output_rfree:   the dim_mX1 vector of instantaneous risk-free rate
%           at time t as a function of m.
%==========================================================================
betta=parameter.betta;
gama=parameter.gama;
a_ou=parameter.a_ou;
sig=parameter.sig;

TTT     = parameter.TTT;
del     = parameter.del_solu;
m_vec   = parameter.m_vec;
q_grid  = parameter.q_solu_grid;

time    = mod(time, TTT);
ind_t   = ceil(time/del);
ind_t   = max(ind_t,1);
q_var   = q_grid(ind_t);

lpr_valu= lpdr_mat(:, ind_t);
fun_data= spdata(0,m_vec,lpr_valu,lpr_valu);
lpr_deri= spvalue(m_vec, fun_data, 1);
output  = gama*sig^2+(gama*lpr_deri+(gama-1)/(a_ou+betta))*q_var;
output_premium= output+(gama-1)/(a_ou+betta)*lpr_deri*(q_var/sig)^2;
output_rfree  = betta+m_vec-gama*sig^2+(1-gama)/(a_ou+betta)*q_var;
end