function lpr_mat=Solve_pdr(lpr_termi, parameter, maxit, tol)

%==========================================================================
%This function use the iterative approach to solve for the price-dividend
%ratio function in Hengjie_Notes01.pdf.
%Here is a brief explanation of the iteration procedure.
%1) Assuming lpr_termi is the pd ratio at the terminal time T, LPDR0 
%contructs the pd ratio funtion over the interval (0,T), in particular, the
%pdr at time 0.
%2) Give the pd ratio at time 0, LPRT uses the SDF on page 5 of the notes
%to compute the pdr at time T. This gives an updated initial guess of the
%pdr at the terminal time T.
%3) We iterate on the above procedure until convergence.
%==========================================================================
%Input: lpr_termi is the initial guess of the log pdr at time T.
%       parameter: is the structure of parameters.
%       maxit and tol are the maximum number of iterations and tolerance
%       for the iteration.
%Output:lpr_termi is the log pdr at time TTT in the previous cycle.
%==========================================================================

if nargin<=3;
    tol=1.e-10;
end
if nargin<=2;
    maxit=2000;
end
dim_m=parameter.dim_m;

epsilon=100;
jjj=1;
while (epsilon>tol && jjj<maxit);
    lpr_mat=LPDR_0(lpr_termi, parameter,'repeat');
    lpr_ini0=lpr_mat(:,1);
    lpr_tnew=LPDRT(lpr_ini0, parameter);
    epsilon=sqrt(sum((lpr_tnew-lpr_termi).^2)/dim_m);
    lpr_termi=lpr_tnew;
    if (jjj/1000==floor(jjj/1000));
        disp(['Total Number of Iteration:   ', num2str(jjj), ...
            '  Residue:', num2str(epsilon)]);
    end
    jjj=jjj+1;
end
disp(['Total Number of Iteration:   ', num2str(jjj), ...
            '  Residue:', num2str(epsilon)]);