function plot_ann_premium(ann_fig_day, ann_fig_hour, ann_fig_drif, n_month, pref_case, parameter)
%==========================================================================
%Input: non_fig
%       ann_fig:
%       n_month: number of months. We assume monthly announcement,
%       therefore the number of month is also the number of cycles.
%==========================================================================
%Output:pre_ann_vec is the vector of announcement premium as a function of
%       the posterior belief m_vec
%       pre_ann is the announcement premium at the mid point of m_vec;
%       figure(non_fig): equity premium on non-announcement days. Here,
%       equity premium is measured in percentage points in annualized terms
%       figure(ann_fig): equity premium on announcement and
%       non-announcement days.
%==========================================================================
dim_m   = parameter.dim_m;
switch pref_case;
    case 'expect'
        parameter.gama  = 0.999999;
        parameter.ssai  = 1.0;
        load pdr_solu_exp lpr_mat fun_data_mat lpr_sse lpr_comp lpr_ini;
    case 'recurs'
        load pdr_solu lpr_mat fun_data_mat lpr_sse lpr_comp lpr_ini;
end
%First, compute the announcement premium.
%==========================================================================
mind_select = ceil(dim_m/2);
lpr_ini0    = lpr_mat(:,1);
EPrice_vec  = EPDRT(lpr_ini0, parameter);
lpr_termi   = LPDRT(lpr_ini0, parameter);
pre_ann_vec = log(EPrice_vec)-lpr_termi;    %the vector of annoucement premium.
pre_ann     = pre_ann_vec(mind_select)*10000;
disp(pre_ann);
%==========================================================================
%Second, compute the daily equity premium on non-announcement days
%==========================================================================
dim_ann_cyc = n_month*30+1; %number of days
time_vec    = linspace (0, n_month/12, dim_ann_cyc)'; %A vector of days
pre_vec=zeros(dim_ann_cyc,1);   %vector of daily risk premium
rfr_vec=zeros(dim_ann_cyc,1);   %vector of daily risk-free

for j_time=1:dim_ann_cyc;
    [ep_vec, rf_vec]=Risk_Pre(lpr_mat, time_vec(j_time), parameter);
    pre_vec(j_time)=ep_vec(mind_select);    %Annualized return
    rfr_vec(j_time)=rf_vec(mind_select);
end
pre_day=pre_vec/360*10000;  %daily return in basis points
rfr_day=rfr_vec/360*10000;  %daily risk-free rate in basis points

%We are no longer plotting premium on non-announcement days
% figure (non_fig);
% plot(time_vec*360, pre_day*360/100,'.'); %We plot annualized return in percentage points
% switch pref_case;
%     case 'recurs'
%         title('Equity Premium on Non-Announcement Days: recursive utility');
%     case 'expect'
%         title('Equity Premium on Non-Announcement Days: expected utility');
% end
% ylabel('Annualized return in percentage points');
% xlabel('Number of Trading Days');
% xlim([0 dim_ann_cyc-1]);
% ylim([pre_day(31)*360*0.98/100 pre_day(31)*360*1.05/100]);
% 
%==========================================================================
%Third, plot risk premium on all days
%==========================================================================
figure(ann_fig_day);
hold on;
for jjj=1:n_month;
    pre_day(jjj*30+1)=pre_day(jjj*30+1)+pre_ann;
    plot(jjj*30, pre_day(jjj*30+1)+rfr_day,'ko');
end
plot(time_vec*360, pre_day+rfr_day,'b.');
plot(time_vec*360, rfr_day,'r--');
hold off;
legend('Expected equity return','Risk-free return');
xlim([0 n_month*30]);
ylim([0 20]);
switch pref_case;
    case 'recurs'
        title('Daily equity premium and risk-free return')
    case 'expect'
        title('Daily return: Expected Utility')
end
xlabel('number of trading days');
ylabel('Basis points');
%==========================================================================
%Third, plot risk premium on all days
%==========================================================================
hours_before=6;
beta_a=2;
beta_b=3;
ttol_vec=linspace(-hours_before+1,2,hours_before+2);  %announcement is 0; This is the vector of hour marks. hours_before+2 hours in total.
prem_vec=(pre_day(30)/8)*ones(1, hours_before+2);   %The vector of hourly returns

tbef_vec =linspace(0,1,1+hours_before);             %A vecotr of CDF that is used to calculate probability of ann for each hour
tbef_grid=linspace(0,1,hours_before*10+1);          %A vector of CDF that is used to plot CDF
Cdf_vec=cdf('Beta', tbef_vec, beta_a, beta_b);
% Cdf_grid=cdf('Beta', tbef_grid, beta_a, beta_b);
Cdf_grid=pdf('Beta', tbef_grid, beta_a, beta_b);

for jjj=1:hours_before;
     prem_vec(jjj)=pre_ann*(Cdf_vec(jjj+1)-Cdf_vec(jjj));
end

figure(ann_fig_drif);

subplot(2,1,1);
ttime_grid=linspace(-hours_before,2,(hours_before+2)*10+1);
plot(ttime_grid, [Cdf_grid 0*ones(1,20)],':', 'Linewidth',3);
ylabel('Probability density');
title('Probability of communication before announcement');
xlim([-hours_before-0.6 2+0.5]);

% subplot1=subplot(2,1,1);
% ttime_grid=linspace(-hours_before,2,(hours_before+2)*10+1);
% plot(ttime_grid, [Cdf_grid ones(1,20)],'o');
% % % Set the remaining axes properties
% set(subplot1,'XTick',[-5.4 -4.4 -3.4 -2.4 -1.4 -0.4 0.6 1.6],'XTickLabel',...
%     {'-5','-4','-3','-2','-1','0','1','2'});
% ylabel('Probability');
% title('Probability of communication before time t');
% xlim([-hours_before-0.6 2+0.5]);

subplot(2,1,2);
bar(ttol_vec, prem_vec,'y');
hold on;
bar(0, prem_vec(hours_before),'b');
xlabel('Number of hours after announcement');
ylabel('Basis points');
title('Hourly return around announcement: FOMC');

% subplot2 =subplot(2,1,2);
% bar(ttol_vec, prem_vec,'y');
% hold on;
% bar(0, prem_vec(hours_before),'b');
% box(subplot2,'on');
% % Set the remaining axes properties
% set(subplot2,'XTick',[-5.4 -4.4 -3.4 -2.4 -1.4 -0.4 0.6 1.6 2.6],'XTickLabel',...
%     {'-6','-5','-4','-3','-2','-1','0','1','2'});

figure(ann_fig_hour);
prem_vec=(pre_day(30)/8)*ones(1, hours_before+2);
prem_vec(hours_before)=prem_vec(hours_before)+pre_ann;
bar(ttol_vec, prem_vec,'y');
hold on;
bar(0, prem_vec(hours_before),'b');
ylim([0 20]);
xlabel('Number of hours after announcement');
ylabel('Basis points');
title('Average hourly return around announcements');
end