function output=spdata(flag,t,z,s)

%This function compute the data needed for shape-preserving interpolation.
%Input: t: a vector of interpolation points. z: function value at the points in t. s: first order derivative at points in t.
%flag: flag=0 indicates s is not availible, the program will compute s by Schumaker's method.
%Output is a matrix of dimension 2*(n-1)+1 by 4. The first column is the augmented interplation nodes. The second to fourth
%column is the coeff on constant, first order term, quadratic term, respectively.
%The output is to be used in spvalue to compute function value and first order derivative.

n=length(t);

t_new=zeros(n,1);
z_new=zeros(n,1);
s_new=zeros(n,1);
[t_new,ix]=sort(t);
for j=1:n;
    z_new(j)=z(ix(j));
    s_new(j)=s(ix(j));
end
t=t_new;
z=z_new;
s=s_new;

L=zeros(n-1,1);
delta=zeros(n-1,1);

for i=1:n-1;
    L(i)=sqrt((t(i+1)-t(i))^2+(z(i+1)-z(i))^2);
    delta(i)=(z(i+1)-z(i))/(t(i+1)-t(i));
end
if flag==0;
    for i=2:n-1;
        s(i)=(L(i-1)*delta(i-1)+L(i)*delta(i))/(L(i-1)+L(i));
    end
    s(1)=(3*delta(1)-s(2))/2;
    s(n)=(3*delta(n-1)-s(n-1))/2;
end

node=zeros(2*(n-1)+1,1);
A=zeros(2*(n-1)+1,1);
B=zeros(2*(n-1)+1,1);
C=zeros(2*(n-1)+1,1);

for i=1:n-1;
    a=s(i)-delta(i);
    b=s(i+1)-delta(i);
    
    if abs(a*b/(abs(z(i))+abs(z(i+1))))>=1.e-10;
        if a*b>=0;
            ksai=(t(i)+t(i+1))/2;
        elseif abs(a)>abs(b);
            ksai=t(i+1)+a*(t(i+1)-t(i))/(s(i+1)-s(i));
        else
            ksai=t(i)+b*(t(i+1)-t(i))/(s(i+1)-s(i));
        end
        alpha=ksai-t(i);
        beta=t(i+1)-ksai;
        sbar=(2*(z(i+1)-z(i))-(alpha*s(i)+beta*s(i+1)))/(t(i+1)-t(i));
    else
        ksai=(t(i)+t(i+1))/2;
        alpha=ksai-t(i);
        beta=t(i+1)-ksai;
        s(i)=delta(i);
        s(i+1)=delta(i);
        sbar=delta(i);
    end
    node(2*(i-1)+1)=t(i);
    node(2*(i-1)+2)=ksai;
    A(2*(i-1)+1)=z(i);
    B(2*(i-1)+1)=s(i);
    C(2*(i-1)+1)=(sbar-s(i))/(2*alpha);
    A(2*(i-1)+2)=z(i)+alpha*s(i)+alpha*(sbar-s(i))/2;
    B(2*(i-1)+2)=sbar;
    C(2*(i-1)+2)=(s(i+1)-sbar)/(2*beta);
end
node(2*(n-1)+1)=t(n);
output=[node A B C];