function output=spvalue(x,data,order)

%This function evaluate function value or first order derivative of the approximated function using data generated by spdata.
%The result is a shape preserving quadratic spline.
%Input: x: a column vector of points at which function value is to be evaluated. data: data generated by spdata.
%       order: order of derivative. Two options, order=0: function value. order=1: first order derivative.
%Output: a vector of function value(first order derivative) at the points given in x.

node=data(:,1);
A=data(:,2);
B=data(:,3);
C=data(:,4);
m=length(node);
dimx=length(x);

value=zeros(dimx,m-1);
ind=zeros(dimx,m);
for i=1:m-1;
    ind(:,i)=sign(x-node(i));
    if order==0;
        value(:,i)=A(i)+B(i)*(x-node(i))+C(i)*(x-node(i)).^2;
    elseif order==1;
        value(:,i)=B(i)+2*C(i)*(x-node(i));
    elseif order==2;
        value(:,i)=2*C(i);
    end
end
    
ind(:,m)=sign(x-node(m));
for j=1:dimx;
    if ind(j,1)==-1;
    %    disp('Warning: extrapolation beyond the left limit of the interval');
    %    disp(j);
    %    disp(abs(x(j)-node(1)));
        ind(j,1)=1;
    elseif ind(j,1)==0;
        ind(j,1)=1;
    elseif ind(j,m)==1;
    %    disp('Warning: extrapolation beyond the right limit of the interval');
    %    disp(j);
    %    disp(abs(x(j)-node(m)));
        ind(j,m)=-1;
    elseif ind(j,m)==0;
        ind(j,m)=-1;
    end
    for k=2:m-1;
        if ind(j,k)==0;
            ind(j,k)=1;
        end
    end
end
output=zeros(dimx,1);
for i=1:m-1;
    mul=(ind(:,i)-ind(:,i+1))/2;
    output=mul.*value(:,i)+output;
end